# References


## Youtube

- [Context Rot: How Increasing Input Tokens Impacts LLM Performance](https://www.youtube.com/watch?v=TUjQuC4ugak)
- [Anthropic Have FINALLY Solved the MCP Context Nightmare](https://www.youtube.com/watch?v=1RpGVqgqLaE)
- [Claude Code Just Fixed MCP's Biggest Problem](https://www.youtube.com/watch?v=itS3f1Y52t0)
- [The end of MCP for ai agents?](https://www.youtube.com/watch?v=D4ImbDGFgIM)
- [Anthropic Just Fixed MCP’s Biggest Problem](https://www.youtube.com/watch?v=TVOoMwkpSRQ)
- [Don't bother with MCP (as a dev)](https://www.youtube.com/watch?v=olvnjDadACI)
- [The BIG Problem with MCP Servers (and the Solution!)](https://www.youtube.com/watch?v=1_z3h2r93OY)
- [Anthropic Have FINALLY Solved the MCP Context Nightmare](https://www.youtube.com/watch?v=1RpGVqgqLaE)
- [This AI Coding Trap Destroys Your Productivity](https://www.youtube.com/watch?v=WmS9_m5n1kU)
- [MCP is the wrong abstraction](https://www.youtube.com/watch?v=bAYZjVAodoo)
- [Anthropic admits that MCP sucks](https://www.youtube.com/watch?v=1piFEKA9XL0)
- [Anthropic is trying SO hard to fix MCP...](https://www.youtube.com/watch?v=hPPTrsUzLA8)

## Alternatives

- Proxy like the Docker MCP Gateway - https://docs.docker.com/ai/mcp-catalog-and-toolkit/mcp-gateway/
- Advanced Tool from Anthropic - https://www.anthropic.com/engineering/advanced-tool-use


## Claude Best Practiceß 

- https://github.com/affaan-m/everything-claude-code